@@ -1,6 +1,7 @@
 """Package for creation of Parametric Map instances."""
 
 from highdicom.pm.content import DimensionIndexSequence, RealWorldValueMapping
+from highdicom.pm.enum import DerivedPixelContrastValues, ImageFlavorValues
 from highdicom.pm.sop import ParametricMap
 
 SOP_CLASS_UIDS = {
@@ -8,7 +9,9 @@ SOP_CLASS_UIDS = {
 }
 
 __all__ = [
+    'DerivedPixelContrastValues',
     'DimensionIndexSequence',
+    'ImageFlavorValues',
     'ParametricMap',
     'RealWorldValueMapping',
 ]
